import{r as l,B as n,j as e,a as u,b as c,c as d,D as B,d as m}from"./index.Bzd-hLkw.js";function p(i){const{disabled:o,element:t,widgetMgr:s,fragmentId:r}=i;let a=n.SECONDARY;return t.type==="primary"?a=n.PRIMARY:t.type==="tertiary"&&(a=n.TERTIARY),e(m,{className:"stButton","data-testid":"stButton",children:e(u,{help:t.help,containerWidth:!0,children:e(c,{kind:a,size:d.SMALL,disabled:o,containerWidth:!0,onClick:()=>s.setTriggerValue(t,{fromUi:!0},r),children:e(B,{icon:t.icon,label:t.label})})})})}const h=l.memo(p);export{h as default};
